==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ABooleanBaseType.h <==
// public final class soot.jimple.parser.node.ABooleanBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9a4f99188674cc9 soot_jimple_parser_node_ABooleanBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ABooleanBaseType_H_
#define _JC_soot_jimple_parser_node_ABooleanBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TBoolean$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs	_jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$refs	_jc_soot_jimple_parser_node_ABooleanBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$object	_jc_soot_jimple_parser_node_ABooleanBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vmethods	_jc_soot_jimple_parser_node_ABooleanBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtable	_jc_soot_jimple_parser_node_ABooleanBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtype	_jc_soot_jimple_parser_node_ABooleanBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$_init$a54dbc1efa1d7f3a(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TBoolean$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$getBoolean$b3242d902e2d62b7(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$setBoolean$b09da0459350c217(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$getBoolean$b3242d902e2d62b7;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$setBoolean$b09da0459350c217;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
	struct _jc_soot_jimple_parser_node_TBoolean$object	*(*getBoolean$b3242d902e2d62b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setBoolean$b09da0459350c217)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vmethods	soot_jimple_parser_node_ABooleanBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TBoolean$object	*__5fboolean__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$refs {
    _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs	soot_jimple_parser_node_ABooleanBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs	soot_jimple_parser_node_ABooleanBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABooleanBaseType$object {
	_jc_soot_jimple_parser_node_ABooleanBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABooleanBaseType$vtype _jc_soot_jimple_parser_node_ABooleanBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABooleanBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABooleanBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABooleanBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ABooleanBaseType.h <==
// public final class soot.jimple.parser.node.ABooleanBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9a4f99188674cc9 soot_jimple_parser_node_ABooleanBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_ABooleanBaseType_H_
#define _JC_soot_jimple_parser_node_ABooleanBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TBoolean$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs	_jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$refs	_jc_soot_jimple_parser_node_ABooleanBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs	_jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABooleanBaseType$object	_jc_soot_jimple_parser_node_ABooleanBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vmethods	_jc_soot_jimple_parser_node_ABooleanBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtable	_jc_soot_jimple_parser_node_ABooleanBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtype	_jc_soot_jimple_parser_node_ABooleanBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$_init$a54dbc1efa1d7f3a(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TBoolean$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$getBoolean$b3242d902e2d62b7(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABooleanBaseType$method$setBoolean$b09da0459350c217(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABooleanBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$getBoolean$b3242d902e2d62b7;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$setBoolean$b09da0459350c217;
extern _jc_method _jc_soot_jimple_parser_node_ABooleanBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TBoolean$object	*(*getBoolean$b3242d902e2d62b7)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setBoolean$b09da0459350c217)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *, struct _jc_soot_jimple_parser_node_TBoolean$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABooleanBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vmethods	soot_jimple_parser_node_ABooleanBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABooleanBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TBoolean$object	*__5fboolean__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$refs {
    _jc_soot_jimple_parser_node_ABooleanBaseType$sub_refs	soot_jimple_parser_node_ABooleanBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_ABooleanBaseType$sub_nonrefs	soot_jimple_parser_node_ABooleanBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABooleanBaseType$object {
	_jc_soot_jimple_parser_node_ABooleanBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABooleanBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABooleanBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABooleanBaseType$vtype _jc_soot_jimple_parser_node_ABooleanBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABooleanBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABooleanBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABooleanBaseType_H_ */
